@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2005, Arun S Konagurthu, The University of Melbourne.
+ * Copyright (c) 2005, Arun S Konagurthu, Monash University.
  * All rights reserved.
  * 
  * Redistribution and use in source and binary forms, with or without
@@ -646,7 +646,7 @@ void CHECK_OPTION_ARGS( CmdLine& CL )
 			}
 		}
 
-		char *buffer = "" ;
+		char *buffer;
 		int n ;
 		switch( indx )
 		{
